@@ -27,6 +27,7 @@ class VariableAcUpdateSync(ReadonlyVariable):
     """
     def get(self):
         action = self.Get("cl_action")
-        if action in ("sync", 'update_profile'):
+        if action in ("sync", 'update_profile') and \
+            not self.Get('cl_merge_pkg'):
             return "on"
         return "off"
