@@ -312,7 +312,8 @@ class VariableClUpdateBinhostData(ReadonlyTableVariable):
     source = ["cl_update_binhost_host",
               "cl_update_binhost_revisions",
               "cl_update_binhost_timestamp",
-              "cl_update_binhost_time"]
+              "cl_update_binhost_time",
+              "cl_update_binhost_level"]
 
     def get(self, hr=HumanReadable.No):
         return Variable.EmptyTable
@@ -367,6 +368,14 @@ class VariableClUpdateBinhostTime(FieldValue, Variable):
     source_variable = "cl_update_binhost_data"
     column = 3
 
+class VariableClUpdateBinhostLevel(FieldValue, Variable):
+    """
+    Список имен прочих репозиториев
+    """
+    type = "list"
+    source_variable = "cl_update_binhost_data"
+    column = 4
+
 
 class VariableClUpdateLastTimestamp(ReadonlyVariable):
     """
@@ -1858,7 +1867,7 @@ class VariableClUpdateLevel(Variable):
     Используется для выбора зеркала
     """
     type = "int"
-    value = "0"
+    value = "-1"
 
 class VariableClUpdateUseMigrationHost(Variable):
     """
@@ -1886,4 +1895,11 @@ class VariableClCheckUpdateLevel(Variable):
     NOT IMPLEMENTED  YET
     """
     type = "bool"
-    value = "on"
\ No newline at end of file
+    value = "on"
+
+class VariableClUpdateMaxLevelFound(Variable):
+    """
+    Самый высокий уровень наиденный на зеркалах
+    """
+    type = "int"
+    value = "0"
\ No newline at end of file
